@@ -9,8 +9,8 @@ make things easier for decompilation.
 import uncompyle6.scanners.scanner32 as scan
 
 # bytecode verification, verify(), uses JUMP_OPs from here
-from xdis.opcodes import opcode_32 as opc  # is this right?
-JUMP_OPs = map(lambda op: opc.opname[op], opc.hasjrel + opc.hasjabs)
+from xdis.opcodes import opcode_32pypy as opc
+JUMP_OPs = opc.JUMP_OPS
 
 # We base this off of 3.2
 class ScannerPyPy32(scan.Scanner32):
@@ -19,4 +19,5 @@ class ScannerPyPy32(scan.Scanner32):
         # pypy 3.2 and 3.2
         scan.Scanner32.__init__(self, show_asm, is_pypy=True)
         self.version = 3.2
+        self.opc = opc
         return
