@@ -279,7 +279,7 @@ class Scanner26(scan.Scanner2):
 
         if show_asm in ('both', 'after'):
             for t in tokens:
-                print(t.format(line_prefix='L.'))
+                print(t.format(line_prefix=""))
             print()
         return tokens, customize
 
