@@ -67,8 +67,7 @@ from __future__ import print_function
 
 import re
 
-from xdis import iscode
-from xdis.magics import sysinfo2float
+from xdis import iscode, sysinfo2float
 from uncompyle6.semantics import pysource
 from uncompyle6 import parser
 from uncompyle6.scanner import Token, Code, get_scanner
@@ -963,7 +962,7 @@ class FragmentsWalker(pysource.SourceWalker, object):
 
         self.prune()
 
-    def n_listcomp(self, node):
+    def n_list_comp(self, node):
         self.write("[")
         if node[0].kind == "load_closure":
             self.listcomprehension_walk2(node)
